import { browser } from "$app/environment";
import { getAuthInfo, makeAuthHeaderForAxios } from "$lib/auth/Auth";
import { makePost } from "$lib/tools/requests/requests";
import { sayError } from "$lib/tools/toaster/Toaster";
import { redirect } from "$lib/tools/url/URLTools";

export async function load({ params }) {
  if (!browser) return;
  const { userToken } = params;
  let userResult = await makePost(
    "getUser",
    {
      token: userToken,
    },
    makeAuthHeaderForAxios(getAuthInfo()?.a)
  );
  if (userResult.status === 401) {
    sayError("Данные авторизации устарели");
    // window.location.href = "/";
    redirect("/admin/");
    return {};
  }
  if (userResult.error) {
    sayError("Не удалось настроить пользователя");
    return {};
  }
  // userResult["can_trade"] = userResult["can_trade"] === "t" ? true : false;
  // userResult["can_trade_global"] =
  //   userResult["can_trade_global"] === "t" ? true : false;
  // userResult["is_withdrawal_available"] =
  //   userResult["is_withdrawal_available"] === "t" ? true : false;
  // userResult["balance"] = Number(userResult["balance"]);
  // userResult["bid"] = Number(userResult["bid"]);
  let userRes = { ...userResult.data };
  userRes["can_trade"] = userRes["can_trade"] === "t" ? true : false;
  userRes["can_trade_global"] =
    userRes["can_trade_global"] === "t" ? true : false;
  userRes["is_withdrawal_available"] =
    userRes["is_withdrawal_available"] === "t" ? true : false;
  userRes["balance"] = Number(userRes["balance"]);
  userRes["bid"] = Number(userRes["bid"]);
  return {
    token: userToken,
    userData: userRes,
  };
}
